@@ -1,15 +1,16 @@
+#![allow(clippy::float_cmp)]
+
 use std::borrow::Cow;
 use std::fs::File;
 use std::io::Read;
-use std::iter;
 use std::str::FromStr;
 use std::sync::Arc;
 
+#[cfg(feature = "num-bigint")]
 use num_bigint::BigInt;
-use smallvec::smallvec;
 
 use jiter::{
-    Jiter, JiterErrorType, JiterResult, JsonErrorType, JsonType, JsonValue, LazyIndexMap, LinePosition, NumberAny,
+    Jiter, JiterErrorType, JiterResult, JsonErrorType, JsonObject, JsonType, JsonValue, LinePosition, NumberAny,
     NumberInt, PartialMode, Peek,
 };
 
@@ -68,7 +69,7 @@ fn json_vec(jiter: &mut Jiter, peek: Option<Peek>) -> JiterResult<Vec<String>> {
             let s = display_number(peek, jiter)?;
             v.push(s);
         }
-    };
+    }
     Ok(v)
 }
 
@@ -79,6 +80,7 @@ fn display_number(peek: Peek, jiter: &mut Jiter) -> JiterResult<String> {
         NumberAny::Int(NumberInt::Int(int)) => {
             format!("Int({int}) @ {position}")
         }
+        #[cfg(feature = "num-bigint")]
         NumberAny::Int(NumberInt::BigInt(big_int)) => {
             format!("BigInt({big_int}) @ {position}")
         }
@@ -115,14 +117,13 @@ macro_rules! single_expect_ok_or_error {
                     Err(e) => {
                         let position = jiter.error_position(e.index);
                         // no wrong type errors, so unwrap the json error
-                        let error_type = match e.error_type {
-                            JiterErrorType::JsonError(ref e) => e,
-                            _ => panic!("unexpected error type: {:?}", e.error_type),
+                        let JiterErrorType::JsonError(error_type) = e.error_type else {
+                            panic!("unexpected error type: {:?}", e.error_type);
                         };
                         let actual_error = format!("{:?} @ {}", error_type, position.short());
                         assert_eq!(actual_error, $expected_error);
 
-                        let full_error = format!("{} at {}", e.error_type, position);
+                        let full_error = format!("{} at {}", error_type, position);
                         let serde_err = serde_json::from_str::<serde_json::Value>($json).unwrap_err();
                         assert_eq!(full_error, serde_err.to_string());
                         return
@@ -136,9 +137,8 @@ macro_rules! single_expect_ok_or_error {
                         e.to_string();
                         let position = jiter.error_position(e.index);
                         // no wrong type errors, so unwrap the json error
-                        let error_type = match e.error_type {
-                            JiterErrorType::JsonError(e) => e,
-                            _ => panic!("unexpected error type: {:?}", e.error_type),
+                        let JiterErrorType::JsonError(error_type) = e.error_type else {
+                            panic!("unexpected error type: {:?}", e.error_type);
                         };
                         let actual_error = format!("{:?} @ {}", error_type, position.short());
                         assert_eq!(actual_error, $expected_error);
@@ -164,9 +164,6 @@ single_tests! {
     int_zero: ok => "0", "Int(0) @ 1:1";
     int_zero_space: ok => "0 ", "Int(0) @ 1:1";
     int_neg: ok => "-1234", "Int(-1234) @ 1:1";
-    big_int: ok => "92233720368547758070", "BigInt(92233720368547758070) @ 1:1";
-    big_int_neg: ok => "-92233720368547758070", "BigInt(-92233720368547758070) @ 1:1";
-    big_int2: ok => "99999999999999999999999999999999999999999999999999", "BigInt(99999999999999999999999999999999999999999999999999) @ 1:1";
     float_pos: ok => "12.34", "Float(12.34) @ 1:1";
     float_neg: ok => "-12.34", "Float(-12.34) @ 1:1";
     float_exp: ok => "2.2e10", "Float(22000000000) @ 1:1";
@@ -178,7 +175,6 @@ single_tests! {
     float_exp_massive2: ok => "2e2147483648", "Float(inf) @ 1:1";
     float_exp_massive3: ok => "2e2147483646", "Float(inf) @ 1:1";
     float_exp_massive4: ok => "2e2147483646", "Float(inf) @ 1:1";
-    float_exp_massive5: ok => "18446744073709551615000.0", "Float(18446744073709552000000) @ 1:1";
     float_exp_massive6: ok => "0.0E667", "Float(0) @ 1:1";
     float_exp_tiny0: ok => "2e-2147483647", "Float(0) @ 1:1";
     float_exp_tiny1: ok => "2e-2147483648", "Float(0) @ 1:1";
@@ -204,8 +200,8 @@ single_tests! {
     bad_null1: err => "nulX", "ExpectedSomeIdent @ 1:4";
     bad_null2: err => "nul", "EofWhileParsingValue @ 1:3";
     object_trailing_comma: err => r#"{"foo": "bar",}"#, "TrailingComma @ 1:15";
-    array_trailing_comma: err => r#"[1, 2,]"#, "TrailingComma @ 1:7";
-    array_wrong_char_after_comma: err => r#"[1, 2,;"#, "ExpectedSomeValue @ 1:7";
+    array_trailing_comma: err => r"[1, 2,]", "TrailingComma @ 1:7";
+    array_wrong_char_after_comma: err => r"[1, 2,;", "ExpectedSomeValue @ 1:7";
     array_end_after_comma: err => "[9,", "EofWhileParsingValue @ 1:3";
     object_wrong_char: err => r#"{"foo":42;"#, "ExpectedObjectCommaOrEnd @ 1:10";
     object_wrong_char_after_comma: err => r#"{"foo":42,;"#, "KeyMustBeAString @ 1:11";
@@ -218,8 +214,8 @@ single_tests! {
     object_null: ok => r#"{"foo": null}"#, "{ @ 1:1, Key(foo), null @ 1:9, }";
     object_bool_compact: ok => r#"{"foo":true}"#, "{ @ 1:1, Key(foo), true @ 1:8, }";
     deep_array: ok => r#"[["Not too deep"]]"#, "[ @ 1:1, [ @ 1:2, String(Not too deep) @ 1:3, ], ]";
-    object_key_int: err => r#"{4: 4}"#, "KeyMustBeAString @ 1:2";
-    array_no_close: err => r#"["#, "EofWhileParsingList @ 1:1";
+    object_key_int: err => r"{4: 4}", "KeyMustBeAString @ 1:2";
+    array_no_close: err => r"[", "EofWhileParsingList @ 1:1";
     array_double_close: err => "[1]]", "TrailingCharacters @ 1:4";
     invalid_float_e_end: err => "0E", "EofWhileParsingValue @ 1:2";
     invalid_float_dot_end: err => "0.", "EofWhileParsingValue @ 1:2";
@@ -235,6 +231,14 @@ single_tests! {
     unexpect_value_xx: err => "xx", "ExpectedSomeValue @ 1:1";
 }
 
+#[cfg(feature = "num-bigint")]
+single_tests! {
+    big_int: ok => "92233720368547758070", "BigInt(92233720368547758070) @ 1:1";
+    big_int_neg: ok => "-92233720368547758070", "BigInt(-92233720368547758070) @ 1:1";
+    big_int2: ok => "99999999999999999999999999999999999999999999999999", "BigInt(99999999999999999999999999999999999999999999999999) @ 1:1";
+    float_exp_massive5: ok => "18446744073709551615000.0", "Float(18446744073709552000000) @ 1:1";
+}
+
 #[test]
 fn invalid_string_controls() {
     let json = "\"123\x08\x0c\n\r\t\"";
@@ -307,9 +311,8 @@ macro_rules! string_test_errors {
                         Err(e) => {
                             // to check to_string works, and for coverage
                             e.to_string();
-                            let error_type = match e.error_type {
-                                JiterErrorType::JsonError(e) => e,
-                                _ => panic!("unexpected error type: {:?}", e.error_type),
+                            let JiterErrorType::JsonError(error_type) = e.error_type else {
+                                panic!("unexpected error type: {:?}", e.error_type);
                             };
                             let position = jiter.error_position(e.index);
                             let actual_error = format!("{:?} @ {} - {}", error_type, e.index, position.short());
@@ -390,7 +393,7 @@ fn utf8_range() {
 fn utf8_range_long() {
     for c in 0u8..255u8 {
         let mut json = vec![b'"', b':', c];
-        json.extend(iter::repeat(b' ').take(20));
+        json.extend(std::iter::repeat(b' ').take(20));
         json.push(b'"');
         // dbg!(c, json.iter().map(|b| *b as char).collect::<Vec<_>>());
 
@@ -411,7 +414,7 @@ fn utf8_range_long() {
 
 #[test]
 fn nan_disallowed() {
-    let json = r#"[NaN]"#;
+    let json = r"[NaN]";
     let mut jiter = Jiter::new(json.as_bytes());
     assert_eq!(jiter.next_array().unwrap().unwrap(), Peek::NaN);
     let e = jiter.next_number().unwrap_err();
@@ -425,7 +428,7 @@ fn nan_disallowed() {
 
 #[test]
 fn inf_disallowed() {
-    let json = r#"[Infinity]"#;
+    let json = r"[Infinity]";
     let mut jiter = Jiter::new(json.as_bytes());
     assert_eq!(jiter.next_array().unwrap().unwrap(), Peek::Infinity);
     let e = jiter.next_number().unwrap_err();
@@ -439,7 +442,7 @@ fn inf_disallowed() {
 
 #[test]
 fn inf_neg_disallowed() {
-    let json = r#"[-Infinity]"#;
+    let json = r"[-Infinity]";
     let mut jiter = Jiter::new(json.as_bytes());
     assert_eq!(jiter.next_array().unwrap().unwrap(), Peek::Minus);
     let e = jiter.next_number().unwrap_err();
@@ -450,7 +453,7 @@ fn inf_neg_disallowed() {
 
 #[test]
 fn num_after() {
-    let json = r#"2:"#; // `:` is 58, directly after 9
+    let json = r"2:"; // `:` is 58, directly after 9
     let mut jiter = Jiter::new(json.as_bytes());
     let num = jiter.next_number().unwrap();
     assert_eq!(num, NumberAny::Int(NumberInt::Int(2)));
@@ -465,7 +468,7 @@ fn num_after() {
 
 #[test]
 fn num_before() {
-    let json = r#"2/"#; // `/` is 47, directly before 0
+    let json = r"2/"; // `/` is 47, directly before 0
     let mut jiter = Jiter::new(json.as_bytes());
     let num = jiter.next_number().unwrap();
     assert_eq!(num, NumberAny::Int(NumberInt::Int(2)));
@@ -480,7 +483,7 @@ fn num_before() {
 
 #[test]
 fn nan_disallowed_wrong_type() {
-    let json = r#"[NaN]"#;
+    let json = r"[NaN]";
     let mut jiter = Jiter::new(json.as_bytes());
     assert_eq!(jiter.next_array().unwrap().unwrap(), Peek::NaN);
     let e = jiter.next_str().unwrap_err();
@@ -494,21 +497,21 @@ fn nan_disallowed_wrong_type() {
 
 #[test]
 fn value_allow_nan_inf() {
-    let json = r#"[1, NaN, Infinity, -Infinity]"#;
+    let json = r"[1, NaN, Infinity, -Infinity]";
     let value = JsonValue::parse(json.as_bytes(), true).unwrap();
-    let expected = JsonValue::Array(Arc::new(smallvec![
+    let expected = JsonValue::Array(Arc::new(vec![
         JsonValue::Int(1),
         JsonValue::Float(f64::NAN),
         JsonValue::Float(f64::INFINITY),
-        JsonValue::Float(f64::NEG_INFINITY)
+        JsonValue::Float(f64::NEG_INFINITY),
     ]));
     // compare debug since `f64::NAN != f64::NAN`
-    assert_eq!(format!("{:?}", value), format!("{:?}", expected));
+    assert_eq!(format!("{value:?}"), format!("{:?}", expected));
 }
 
 #[test]
 fn value_disallow_nan() {
-    let json = r#"[1, NaN]"#;
+    let json = r"[1, NaN]";
     let err = JsonValue::parse(json.as_bytes(), false).unwrap_err();
     assert_eq!(err.error_type, JsonErrorType::ExpectedSomeValue);
     assert_eq!(err.description(json.as_bytes()), "expected value at line 1 column 5");
@@ -573,7 +576,7 @@ fn parse_zero_float() {
     match v {
         JsonValue::Float(v) => assert!((0.1234 - v).abs() < 1e-6),
         other => panic!("unexpected value: {other:?}"),
-    };
+    }
 }
 
 #[test]
@@ -582,7 +585,7 @@ fn parse_zero_exp_float() {
     match v {
         JsonValue::Float(v) => assert!((120.0 - v).abs() < 1e-3),
         other => panic!("unexpected value: {other:?}"),
-    };
+    }
 }
 
 #[test]
@@ -600,7 +603,7 @@ fn bad_high_order_string() {
     let e = JsonValue::parse(&bytes, false).unwrap_err();
     assert_eq!(e.error_type, JsonErrorType::InvalidUnicodeCodePoint);
     assert_eq!(e.index, 4);
-    assert_eq!(e.description(&bytes), "invalid unicode code point at line 1 column 5")
+    assert_eq!(e.description(&bytes), "invalid unicode code point at line 1 column 5");
 }
 
 #[test]
@@ -612,7 +615,7 @@ fn bad_high_order_string_tail() {
     let e = JsonValue::parse(&bytes, false).unwrap_err();
     assert_eq!(e.error_type, JsonErrorType::InvalidUnicodeCodePoint);
     assert_eq!(e.index, 4);
-    assert_eq!(e.description(&bytes), "invalid unicode code point at line 1 column 5")
+    assert_eq!(e.description(&bytes), "invalid unicode code point at line 1 column 5");
 }
 
 #[test]
@@ -622,21 +625,20 @@ fn invalid_escape_position() {
     let e = JsonValue::parse(bytes, false).unwrap_err();
     assert_eq!(e.error_type, JsonErrorType::InvalidEscape);
     assert_eq!(e.index, 8);
-    assert_eq!(e.description(bytes), "invalid escape at line 1 column 9")
+    assert_eq!(e.description(bytes), "invalid escape at line 1 column 9");
 }
 
 #[test]
 fn simd_string_sizes() {
     for i in 0..100 {
         let mut json = vec![b'"'];
-        json.extend(iter::repeat(b'a').take(i));
+        json.extend(std::iter::repeat(b'a').take(i));
         json.push(b'"');
-        json.extend(iter::repeat(b' ').take(40));
+        json.extend(std::iter::repeat(b' ').take(40));
 
         let value = JsonValue::parse(&json, false).unwrap();
-        let s = match value {
-            JsonValue::Str(s) => s,
-            _ => panic!("unexpected value {value:?}"),
+        let JsonValue::Str(s) = value else {
+            panic!("unexpected value {value:?}");
         };
         assert_eq!(s.len(), i);
         assert!(s.as_bytes().iter().all(|&b| b == b'a'));
@@ -658,17 +660,18 @@ fn json_value_object() {
     let json = r#"{"foo": "bar", "spam": [1, null, true]}"#;
     let v = JsonValue::parse(json.as_bytes(), false).unwrap();
 
-    let mut expected = LazyIndexMap::new();
-    expected.insert("foo".into(), JsonValue::Str("bar".into()));
-    expected.insert(
-        "spam".into(),
-        JsonValue::Array(Arc::new(smallvec![
-            JsonValue::Int(1),
-            JsonValue::Null,
-            JsonValue::Bool(true)
-        ])),
-    );
-    assert_eq!(v, JsonValue::Object(Arc::new(expected)));
+    let expected = JsonValue::Object(Arc::new(vec![
+        ("foo".into(), JsonValue::Str("bar".into())),
+        (
+            "spam".into(),
+            JsonValue::Array(Arc::new(vec![
+                JsonValue::Int(1),
+                JsonValue::Null,
+                JsonValue::Bool(true),
+            ])),
+        ),
+    ]));
+    assert_eq!(v, expected);
 }
 
 #[test]
@@ -676,21 +679,21 @@ fn json_value_string() {
     let json = r#"["foo", "\u00a3", "\""]"#;
     let v = JsonValue::parse(json.as_bytes(), false).unwrap();
 
-    let expected = JsonValue::Array(Arc::new(smallvec![
+    let expected = JsonValue::Array(Arc::new(vec![
         JsonValue::Str("foo".into()),
         JsonValue::Str("£".into()),
-        JsonValue::Str("\"".into())
+        JsonValue::Str("\"".into()),
     ]));
     assert_eq!(v, expected);
 }
 
 #[test]
 fn parse_array_3() {
-    let json = r#"[1   , null, true]"#;
+    let json = r"[1   , null, true]";
     let v = JsonValue::parse(json.as_bytes(), false).unwrap();
     assert_eq!(
         v,
-        JsonValue::Array(Arc::new(smallvec![
+        JsonValue::Array(Arc::new(vec![
             JsonValue::Int(1),
             JsonValue::Null,
             JsonValue::Bool(true)
@@ -700,9 +703,9 @@ fn parse_array_3() {
 
 #[test]
 fn parse_array_empty() {
-    let json = r#"[   ]"#;
+    let json = r"[   ]";
     let v = JsonValue::parse(json.as_bytes(), false).unwrap();
-    assert_eq!(v, JsonValue::Array(Arc::new(smallvec![])));
+    assert_eq!(v, JsonValue::Array(Arc::new(vec![])));
 }
 
 #[test]
@@ -715,23 +718,23 @@ fn repeat_trailing_array() {
 
 #[test]
 fn parse_value_nested() {
-    let json = r#"[1, 2, [3, 4], 5, 6]"#;
+    let json = r"[1, 2, [3, 4], 5, 6]";
     let v = JsonValue::parse(json.as_bytes(), false).unwrap();
     assert_eq!(
         v,
-        JsonValue::Array(Arc::new(smallvec![
+        JsonValue::Array(Arc::new(vec![
             JsonValue::Int(1),
             JsonValue::Int(2),
-            JsonValue::Array(Arc::new(smallvec![JsonValue::Int(3), JsonValue::Int(4)])),
+            JsonValue::Array(Arc::new(vec![JsonValue::Int(3), JsonValue::Int(4)])),
             JsonValue::Int(5),
             JsonValue::Int(6),
         ]),)
-    )
+    );
 }
 
 #[test]
 fn test_array_trailing() {
-    let json = br#"[1, 2,]"#;
+    let json = br"[1, 2,]";
     let e = JsonValue::parse(json, false).unwrap_err();
     assert_eq!(e.error_type, JsonErrorType::TrailingComma);
     assert_eq!(e.get_position(json), LinePosition::new(1, 7));
@@ -752,7 +755,7 @@ fn pass1_to_value() {
     let v = JsonValue::parse(json_data, false).unwrap();
     let array = match v {
         JsonValue::Array(array) => array,
-        v => panic!("expected array, not {:?}", v),
+        v => panic!("expected array, not {v:?}"),
     };
     assert_eq!(array.len(), 20);
     assert_eq!(array[0], JsonValue::Str("JSON Test Pattern pass1".into()));
@@ -774,9 +777,9 @@ fn escaped_string() {
     let v = JsonValue::parse(json_data, false).unwrap();
     let s = match v {
         JsonValue::Str(s) => s,
-        v => panic!("expected array, not {:?}", v),
+        v => panic!("expected array, not {v:?}"),
     };
-    dbg!(s);
+    drop(s);
     // assert_eq!(s, r#"&#34; " %22 0x22 034 &#x22;"#);
 }
 
@@ -814,9 +817,9 @@ fn jiter_inf() {
 fn jiter_bool() {
     let mut jiter = Jiter::new(b"[true, false, null]");
     assert_eq!(jiter.next_array().unwrap(), Some(Peek::True));
-    assert_eq!(jiter.next_bool().unwrap(), true);
+    assert!(jiter.next_bool().unwrap());
     assert_eq!(jiter.array_step().unwrap(), Some(Peek::False));
-    assert_eq!(jiter.next_bool().unwrap(), false);
+    assert!(!jiter.next_bool().unwrap());
     assert_eq!(jiter.array_step().unwrap(), Some(Peek::Null));
     jiter.next_null().unwrap();
     assert_eq!(jiter.array_step().unwrap(), None);
@@ -829,14 +832,14 @@ fn jiter_bytes() {
     assert_eq!(jiter.next_object_bytes().unwrap().unwrap(), b"foo");
     assert_eq!(jiter.next_bytes().unwrap(), b"bar");
     assert_eq!(jiter.next_key_bytes().unwrap().unwrap(), b"new-line");
-    assert_eq!(jiter.next_bytes().unwrap(), br#"\\n"#);
+    assert_eq!(jiter.next_bytes().unwrap(), br"\\n");
     assert_eq!(jiter.next_key_bytes().unwrap(), None);
     jiter.finish().unwrap();
 }
 
 #[test]
 fn jiter_number() {
-    let mut jiter = Jiter::new(br#"  [1, 2.2, 3, 4.1, 5.67]"#);
+    let mut jiter = Jiter::new(br"  [1, 2.2, 3, 4.1, 5.67]");
     assert_eq!(jiter.next_array().unwrap().unwrap().into_inner(), b'1');
     assert_eq!(jiter.next_int().unwrap(), NumberInt::Int(1));
     assert_eq!(jiter.array_step().unwrap().unwrap().into_inner(), b'2');
@@ -918,36 +921,6 @@ fn test_crazy_massive_int() {
     jiter.finish().unwrap();
 }
 
-#[test]
-fn unique_iter_object() {
-    let value = JsonValue::parse(br#" {"x": 1, "x": 2} "#, false).unwrap();
-    if let JsonValue::Object(obj) = value {
-        assert_eq!(obj.len(), 1);
-        let mut unique = obj.iter_unique();
-        let first = unique.next().unwrap();
-        assert_eq!(first.0, "x");
-        assert_eq!(first.1, &JsonValue::Int(2));
-        assert!(unique.next().is_none());
-    } else {
-        panic!("expected object");
-    }
-}
-
-#[test]
-fn unique_iter_object_repeat() {
-    let value = JsonValue::parse(br#" {"x": 1, "x": 1} "#, false).unwrap();
-    if let JsonValue::Object(obj) = value {
-        assert_eq!(obj.len(), 1);
-        let mut unique = obj.iter_unique();
-        let first = unique.next().unwrap();
-        assert_eq!(first.0, "x");
-        assert_eq!(first.1, &JsonValue::Int(1));
-        assert!(unique.next().is_none());
-    } else {
-        panic!("expected object");
-    }
-}
-
 #[test]
 fn test_recursion_limit() {
     let json = (0..2000).map(|_| "[").collect::<String>();
@@ -961,7 +934,7 @@ fn test_recursion_limit() {
 #[test]
 fn test_recursion_limit_incr() {
     let json = (0..2000).map(|_| "[1]".to_string()).collect::<Vec<_>>().join(", ");
-    let json = format!("[{}]", json);
+    let json = format!("[{json}]");
     let bytes = json.as_bytes();
     let value = JsonValue::parse(bytes, false).unwrap();
     match value {
@@ -1034,9 +1007,10 @@ number_bytes! {
     number_bytes_exp_decimal: b" 123.456e4 " => b"123.456e4";
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn test_4300_int() {
-    let json = (0..4300).map(|_| "9".to_string()).collect::<Vec<_>>().join("");
+    let json = (0..4300).map(|_| "9".to_string()).collect::<String>();
     let bytes = json.as_bytes();
     let value = JsonValue::parse(bytes, false).unwrap();
     let expected_big_int = BigInt::from_str(&json).unwrap();
@@ -1044,17 +1018,18 @@ fn test_4300_int() {
         JsonValue::BigInt(v) => {
             assert_eq!(v, expected_big_int);
         }
-        _ => panic!("expected array, got {:?}", value),
+        _ => panic!("expected array, got {value:?}"),
     }
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn test_big_int_errs() {
     for json in [
         &[b'9'; 4302][..],
         &[b'9'; 5900][..],
         // If the check is only done at the end, this will hang
-        &[b'9'; 10usize.pow(7)][..],
+        &vec![b'9'; 10usize.pow(7)],
     ] {
         let e = JsonValue::parse(json, false).unwrap_err();
         assert_eq!(e.error_type, JsonErrorType::NumberOutOfRange);
@@ -1063,67 +1038,6 @@ fn test_big_int_errs() {
     }
 }
 
-#[test]
-fn lazy_index_map_pretty() {
-    let mut map: LazyIndexMap<Cow<'_, str>, JsonValue<'_>> = LazyIndexMap::new();
-    assert!(map.is_empty());
-    map.insert("foo".into(), JsonValue::Str("bar".into()));
-    assert!(!map.is_empty());
-    map.insert("spam".into(), JsonValue::Null);
-    assert_eq!(format!("{map:?}"), r#"{"foo": Str("bar"), "spam": Null}"#);
-    let keys = map.keys().collect::<Vec<_>>();
-    assert_eq!(keys, vec!["foo", "spam"]);
-}
-
-#[test]
-fn lazy_index_map_small_get() {
-    let mut map: LazyIndexMap<Cow<'_, str>, JsonValue<'_>> = LazyIndexMap::new();
-    map.insert("foo".into(), JsonValue::Str("bar".into()));
-    map.insert("spam".into(), JsonValue::Null);
-
-    assert_eq!(map.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map.get("other"), None);
-}
-
-#[test]
-fn lazy_index_map_big_get() {
-    let mut map: LazyIndexMap<Cow<'_, str>, JsonValue<'_>> = LazyIndexMap::new();
-
-    for i in 0..25 {
-        let key = i.to_string().into();
-        map.insert(key, JsonValue::Int(i));
-    }
-
-    assert_eq!(map.get("0"), Some(&JsonValue::Int(0)));
-    assert_eq!(map.get("10"), Some(&JsonValue::Int(10)));
-    assert_eq!(map.get("22"), Some(&JsonValue::Int(22)));
-    assert_eq!(map.get("other"), None);
-}
-
-#[test]
-fn lazy_index_map_clone() {
-    let mut map: LazyIndexMap<Cow<'_, str>, JsonValue<'_>> = LazyIndexMap::default();
-
-    map.insert("foo".into(), JsonValue::Str("bar".into()));
-    map.insert("spam".into(), JsonValue::Null);
-
-    assert_eq!(map.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map.get("other"), None);
-
-    let map2 = map.clone();
-    assert_eq!(map2.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map2.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map2.get("spam"), Some(&JsonValue::Null));
-    assert_eq!(map2.get("foo"), Some(&JsonValue::Str("bar".into())));
-    assert_eq!(map2.get("other"), None);
-}
-
 #[test]
 fn readme_jiter() {
     let json_data = r#"
@@ -1157,7 +1071,7 @@ fn readme_jiter() {
 
 #[test]
 fn jiter_clone() {
-    let json = r#"[1, 2]"#;
+    let json = r"[1, 2]";
     let mut jiter1 = Jiter::new(json.as_bytes());
     assert_eq!(jiter1.next_array().unwrap().unwrap().into_inner(), b'1');
     let n = jiter1.next_number().unwrap();
@@ -1289,23 +1203,25 @@ fn value_owned() -> JsonValue<'static> {
     JsonValue::parse_owned(s.as_bytes(), false, PartialMode::Off).unwrap()
 }
 
+fn get_key<'a, 'j>(o: &'a JsonObject<'j>, key: &str) -> Option<&'a JsonValue<'j>> {
+    o.iter().find_map(|(k, v)| (k == key).then_some(v))
+}
+
 #[test]
 fn test_owned_value() {
     let value = value_owned();
-    let obj = match value {
-        JsonValue::Object(obj) => obj,
-        _ => panic!("expected object"),
+    let JsonValue::Object(obj) = value else {
+        panic!("expected object")
     };
-    assert_eq!(obj.get("int").unwrap(), &JsonValue::Int(1));
-    assert_eq!(obj.get("const").unwrap(), &JsonValue::Bool(true));
-    assert_eq!(obj.get("float").unwrap(), &JsonValue::Float(1.2));
-    let array = match obj.get("array").unwrap() {
-        JsonValue::Array(array) => array,
-        _ => panic!("expected array"),
+    assert_eq!(get_key(&obj, "int").unwrap(), &JsonValue::Int(1));
+    assert_eq!(get_key(&obj, "const").unwrap(), &JsonValue::Bool(true));
+    assert_eq!(get_key(&obj, "float").unwrap(), &JsonValue::Float(1.2));
+    let JsonValue::Array(array) = get_key(&obj, "array").unwrap() else {
+        panic!("expected array")
     };
     assert_eq!(
         array,
-        &Arc::new(smallvec![JsonValue::Int(1), JsonValue::Bool(false), JsonValue::Null])
+        &Arc::new(vec![JsonValue::Int(1), JsonValue::Bool(false), JsonValue::Null])
     );
 }
 
@@ -1316,24 +1232,23 @@ fn value_into_static() -> JsonValue<'static> {
     jiter.into_static()
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn test_into_static() {
     let value = crate::value_into_static();
-    let obj = match value {
-        JsonValue::Object(obj) => obj,
-        _ => panic!("expected object"),
+    let JsonValue::Object(obj) = value else {
+        panic!("expected object")
     };
     let expected_big_int = BigInt::from_str("92233720368547758070").unwrap();
-    assert_eq!(obj.get("big_int").unwrap(), &JsonValue::BigInt(expected_big_int));
-    assert_eq!(obj.get("const").unwrap(), &JsonValue::Bool(true));
-    assert_eq!(obj.get("float").unwrap(), &JsonValue::Float(1.2));
-    let array = match obj.get("array").unwrap() {
-        JsonValue::Array(array) => array,
-        _ => panic!("expected array"),
+    assert_eq!(get_key(&obj, "big_int").unwrap(), &JsonValue::BigInt(expected_big_int));
+    assert_eq!(get_key(&obj, "const").unwrap(), &JsonValue::Bool(true));
+    assert_eq!(get_key(&obj, "float").unwrap(), &JsonValue::Float(1.2));
+    let JsonValue::Array(array) = get_key(&obj, "array").unwrap() else {
+        panic!("expected array")
     };
     assert_eq!(
         array,
-        &Arc::new(smallvec![
+        &Arc::new(vec![
             JsonValue::Int(1),
             JsonValue::Bool(false),
             JsonValue::Null,
@@ -1346,9 +1261,8 @@ fn test_into_static() {
 fn jiter_next_value_borrowed() {
     let mut jiter = Jiter::new(br#" "v"  "#);
     let v = jiter.next_value().unwrap();
-    let s = match v {
-        JsonValue::Str(s) => s,
-        _ => panic!("expected string"),
+    let JsonValue::Str(s) = v else {
+        panic!("expected string")
     };
     assert_eq!(s, "v");
     assert!(matches!(s, Cow::Borrowed(_)));
@@ -1358,14 +1272,14 @@ fn jiter_next_value_borrowed() {
 fn jiter_next_value_owned() {
     let mut jiter = Jiter::new(br#" "v"  "#);
     let v = jiter.next_value_owned().unwrap();
-    let s = match v {
-        JsonValue::Str(s) => s,
-        _ => panic!("expected string"),
+    let JsonValue::Str(s) = v else {
+        panic!("expected string")
     };
     assert_eq!(s, "v");
     assert!(matches!(s, Cow::Owned(_)));
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn i64_max() {
     let json = "9223372036854775807";
@@ -1378,6 +1292,7 @@ fn i64_max() {
     }
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn test_all_int_lengths() {
     for int_size in 1..100 {
@@ -1399,12 +1314,16 @@ fn test_number_int_try_from_bytes() {
     let n: NumberInt = b"0".as_ref().try_into().unwrap();
     assert_eq!(n, NumberInt::Int(0));
 
-    let twenty_nines = "9".repeat(29);
-    let n: NumberInt = twenty_nines.as_bytes().try_into().unwrap();
-    match n {
-        NumberInt::BigInt(v) => assert_eq!(v.to_string(), twenty_nines),
-        _ => panic!("expected big int"),
+    #[cfg(feature = "num-bigint")]
+    {
+        let twenty_nines = "9".repeat(29);
+        let n: NumberInt = twenty_nines.as_bytes().try_into().unwrap();
+        match n {
+            NumberInt::BigInt(v) => assert_eq!(v.to_string(), twenty_nines),
+            NumberInt::Int(_) => panic!("expected big int"),
+        }
     }
+
     let e = NumberInt::try_from(b"x23".as_ref()).unwrap_err();
     assert_eq!(e.to_string(), "invalid number at index 0");
 
@@ -1423,9 +1342,12 @@ fn test_number_int_try_from_bytes() {
     let e = NumberInt::try_from(b"0123".as_ref()).unwrap_err();
     assert_eq!(e.to_string(), "invalid number at index 1");
 
-    let too_long = "9".repeat(4309);
-    let e = NumberInt::try_from(too_long.as_bytes()).unwrap_err();
-    assert_eq!(e.to_string(), "number out of range at index 4301");
+    #[cfg(feature = "num-bigint")]
+    {
+        let too_long = "9".repeat(4309);
+        let e = NumberInt::try_from(too_long.as_bytes()).unwrap_err();
+        assert_eq!(e.to_string(), "number out of range at index 4301");
+    }
 }
 
 #[test]
@@ -1552,7 +1474,7 @@ fn jiter_skip_backslash_strings() {
 
 #[test]
 fn jiter_skip_invalid_ident() {
-    let mut jiter = Jiter::new(br#"trUe"#).with_allow_inf_nan();
+    let mut jiter = Jiter::new(br"trUe").with_allow_inf_nan();
     let e = jiter.next_skip().unwrap_err();
     assert_eq!(
         e.error_type,
@@ -1572,14 +1494,14 @@ fn jiter_skip_invalid_string() {
 
 #[test]
 fn jiter_skip_invalid_int() {
-    let mut jiter = Jiter::new(br#"01"#);
+    let mut jiter = Jiter::new(br"01");
     let e = jiter.next_skip().unwrap_err();
     assert_eq!(e.error_type, JiterErrorType::JsonError(JsonErrorType::InvalidNumber));
 }
 
 #[test]
 fn jiter_skip_invalid_object() {
-    let mut jiter = Jiter::new(br#"{{"#);
+    let mut jiter = Jiter::new(br"{{");
     let e = jiter.next_skip().unwrap_err();
     assert_eq!(e.error_type, JiterErrorType::JsonError(JsonErrorType::KeyMustBeAString));
 }
@@ -1615,7 +1537,7 @@ fn jiter_skip_invalid_string_high() {
 
 #[test]
 fn jiter_skip_invalid_long_float() {
-    let mut jiter = Jiter::new(br#"2121515572557277572557277e"#);
+    let mut jiter = Jiter::new(br"2121515572557277572557277e");
     let e = jiter.next_skip().unwrap_err();
     assert_eq!(
         e.error_type,
@@ -1623,9 +1545,10 @@ fn jiter_skip_invalid_long_float() {
     );
 }
 
+#[cfg(feature = "num-bigint")]
 #[test]
 fn jiter_value_invalid_long_float() {
-    let e = JsonValue::parse(br#"2121515572557277572557277e"#, false).unwrap_err();
+    let e = JsonValue::parse(br"2121515572557277572557277e", false).unwrap_err();
     assert_eq!(e.error_type, JsonErrorType::EofWhileParsingValue);
 }
 
@@ -1646,9 +1569,8 @@ fn test_unicode_roundtrip() {
     // '"中文"'
     let json_bytes = b"\"\\u4e2d\\u6587\"";
     let value = JsonValue::parse(json_bytes, false).unwrap();
-    let cow = match value {
-        JsonValue::Str(s) => s,
-        _ => panic!("expected string"),
+    let JsonValue::Str(cow) = value else {
+        panic!("expected string")
     };
     assert_eq!(cow, "中文");
     assert!(matches!(cow, Cow::Owned(_)));
@@ -1660,7 +1582,7 @@ fn test_value_partial_array_on() {
     let value = JsonValue::parse_with_config(json_bytes, false, PartialMode::On).unwrap();
     assert_eq!(
         value,
-        JsonValue::Array(Arc::new(smallvec![
+        JsonValue::Array(Arc::new(vec![
             JsonValue::Str("string".into()),
             JsonValue::Bool(true),
             JsonValue::Null,
@@ -1681,7 +1603,7 @@ fn test_value_partial_array_trailing_strings() {
     let value = JsonValue::parse_with_config(json_bytes, false, PartialMode::TrailingStrings).unwrap();
     assert_eq!(
         value,
-        JsonValue::Array(Arc::new(smallvec![
+        JsonValue::Array(Arc::new(vec![
             JsonValue::Str("string".into()),
             JsonValue::Bool(true),
             JsonValue::Null,
@@ -1701,9 +1623,8 @@ fn test_value_partial_array_trailing_strings() {
 fn test_value_partial_object() {
     let json_bytes = br#"{"a": "value", "b": true, "c": false, "d": null, "e": 1, "f": 2.22, "g": ["#;
     let value = JsonValue::parse_with_config(json_bytes, false, PartialMode::TrailingStrings).unwrap();
-    let obj = match value {
-        JsonValue::Object(obj) => obj,
-        _ => panic!("expected object"),
+    let JsonValue::Object(obj) = value else {
+        panic!("expected object")
     };
     assert_eq!(obj.len(), 7);
     let pairs = obj.iter().collect::<Vec<_>>();
@@ -1715,7 +1636,7 @@ fn test_value_partial_object() {
     assert_eq!(pairs[5].clone(), (Cow::Borrowed("f"), JsonValue::Float(2.22)));
     assert_eq!(
         pairs[6].clone(),
-        (Cow::Borrowed("g"), JsonValue::Array(Arc::new(smallvec![])))
+        (Cow::Borrowed("g"), JsonValue::Array(Arc::new(vec![])))
     );
     // test all position in the string
     for i in 1..json_bytes.len() {
